aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/lib/surface/channel.cc
diff options
context:
space:
mode:
authorGravatar ncteisen <ncteisen@gmail.com>2018-03-05 22:53:44 -0800
committerGravatar ncteisen <ncteisen@gmail.com>2018-03-05 22:53:44 -0800
commit7d90d5497c2115599665728056c818efc575b4c4 (patch)
tree97a1ac0e30bbd3e1c9730cbcda1ce784ffd6ba96 /src/core/lib/surface/channel.cc
parentac945eba98a11795faaa41b5d93fe27a8b5a89df (diff)
Reviewer feedback
Diffstat (limited to 'src/core/lib/surface/channel.cc')
-rw-r--r--src/core/lib/surface/channel.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/core/lib/surface/channel.cc b/src/core/lib/surface/channel.cc
index 1488736c49..fb435b9881 100644
--- a/src/core/lib/surface/channel.cc
+++ b/src/core/lib/surface/channel.cc
@@ -21,6 +21,7 @@
#include "src/core/lib/surface/channel.h"
#include <inttypes.h>
+#include <limits.h>
#include <stdlib.h>
#include <string.h>
@@ -173,8 +174,8 @@ grpc_channel* grpc_channel_create_with_builder(
} else if (0 == strcmp(args->args[i].key,
GRPC_ARG_MAX_CHANNEL_TRACE_EVENTS_PER_NODE)) {
GPR_ASSERT(channel_tracer_max_nodes == 0);
- // max_nodes defaults to 0 (which is off), clamped between 0 and 100.
- const grpc_integer_options options = {0, 0, 100};
+ // max_nodes defaults to 0 (which is off), clamped between 0 and INT_MAX
+ const grpc_integer_options options = {0, 0, INT_MAX};
channel_tracer_max_nodes =
(size_t)grpc_channel_arg_get_integer(&args->args[i], options);
}